import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as Accordion from '@radix-ui/react-accordion';
import { interpolateString } from '@tutorialkit/types';
import { AnimatePresence, cubicBezier, motion } from 'framer-motion';
import { useCallback, useRef, useState } from 'react';
import { useOutsideClick } from './hooks/useOutsideClick.js';
import navStyles from './styles/nav.module.css';
import { classNames } from './utils/classnames.js';
const dropdownEasing = cubicBezier(0.4, 0, 0.2, 1);
export function Nav({ lesson: currentLesson, navList }) {
    const menuRef = useRef(null);
    const [showDropdown, setShowDropdown] = useState(false);
    const { prev, next } = currentLesson;
    const onOutsideClick = useCallback(() => {
        setShowDropdown(false);
    }, []);
    useOutsideClick(menuRef, onOutsideClick);
    return (_jsxs("header", { className: "grid grid-cols-1 sm:grid-cols-[auto_minmax(0,1fr)_auto] h-[82px] gap-0.5 py-4 px-1 text-sm", children: [_jsx("a", { className: classNames('hidden sm:flex cursor-pointer h-full items-center justify-center w-[40px] text-tk-elements-breadcrumbs-navButton-iconColor', !prev ? 'opacity-32 pointer-events-none' : 'hover:text-tk-elements-breadcrumbs-navButton-iconColorHover'), "aria-disabled": !prev, href: prev?.href, children: _jsx("span", { className: "i-ph-arrow-left scale-120" }) }), _jsx("div", { className: "relative", children: _jsxs("div", { "data-state": `${showDropdown ? 'open' : 'closed'}`, className: classNames(navStyles.NavContainer, 'absolute mx-4 sm:mx-0 z-1 left-0 right-0 rounded-[8px] border overflow-hidden z-50'), ref: menuRef, children: [_jsxs("button", { className: classNames(navStyles.ToggleButton, 'flex-1 flex items-center text-left py-3 px-3 w-full overflow-hidden'), onClick: () => setShowDropdown(!showDropdown), children: [_jsxs("div", { className: "flex items-center gap-1 font-light truncate", children: [_jsx("span", { className: "hidden sm:inline", children: currentLesson.part.title }), _jsx("span", { className: classNames('hidden sm:inline', navStyles.Divider), children: "/" }), _jsx("span", { className: "hidden sm:inline", children: currentLesson.chapter.title }), _jsx("span", { className: classNames('hidden sm:inline', navStyles.Divider), children: "/" }), _jsx("strong", { className: "font-semibold", children: currentLesson.data.title })] }), _jsx("div", { className: classNames(navStyles.ToggleButtonIcon, 'ml-auto w-[30px]', {
                                        'i-ph-caret-up-bold': showDropdown,
                                        'i-ph-caret-down-bold': !showDropdown,
                                    }) })] }), _jsx(AnimatePresence, { children: showDropdown && (_jsx(motion.nav, { initial: { height: 0, y: 0 }, animate: { height: 'auto', y: 0 }, exit: { height: 0, y: 0 }, transition: { duration: 0.2, ease: dropdownEasing }, className: " overflow-hidden transition-theme bg-tk-elements-breadcrumbs-dropdown-backgroundColor", children: renderParts(navList, currentLesson, onOutsideClick) })) })] }) }), _jsx("a", { className: classNames('hidden sm:flex cursor-pointer h-full items-center justify-center w-[40px] text-tk-elements-breadcrumbs-navButton-iconColor', !next ? 'opacity-32 pointer-events-none' : 'hover:text-tk-elements-breadcrumbs-navButton-iconColorHover'), "aria-disabled": !next, href: next?.href, children: _jsx("span", { className: "i-ph-arrow-right scale-120" }) })] }));
}
function renderParts(navList, currentLesson, onLinkClick) {
    return (_jsx("ul", { className: "py-5 pl-5 border-t border-tk-elements-breadcrumbs-dropdown-borderColor overflow-auto max-h-[60dvh]", children: _jsx(Accordion.Root, { className: "space-y-1.5", type: "single", collapsible: true, defaultValue: `part-${currentLesson.part.id}`, children: navList.map((part, partIndex) => {
                const isPartActive = part.id === currentLesson.part.id;
                return (_jsx("li", { children: _jsxs(Accordion.Item, { value: `part-${part.id}`, children: [_jsxs(Accordion.Trigger, { className: classNames(navStyles.AccordionTrigger, 'flex items-center gap-1 w-full hover:text-primary-700', {
                                    [`font-semibold ${navStyles.AccordionTriggerActive}`]: isPartActive,
                                }), children: [_jsx("span", { className: `${navStyles.AccordionTriggerIcon} i-ph-caret-right-bold scale-80` }), _jsx("span", { children: interpolateString(currentLesson.data.i18n.partTemplate, {
                                            index: partIndex + 1,
                                            title: part.title,
                                        }) })] }), _jsx(Accordion.Content, { className: navStyles.AccordionContent, children: renderChapters(currentLesson, part, isPartActive, onLinkClick) })] }) }, partIndex));
            }) }) }));
}
function renderChapters(currentLesson, part, isPartActive, onLinkClick) {
    return (_jsx("ul", { className: "pl-4.5 mt-1.5", children: _jsx(Accordion.Root, { className: "mb-1 space-y-1.5", type: "single", collapsible: true, defaultValue: `chapter-${currentLesson.chapter.id}`, children: part.sections?.map((chapter, chapterIndex) => {
                const isChapterActive = isPartActive && currentLesson.chapter.id === chapter.id;
                return (_jsx("li", { className: "", children: _jsxs(Accordion.Item, { value: `chapter-${chapter.id}`, children: [_jsxs(Accordion.Trigger, { className: classNames(navStyles.AccordionTrigger, 'flex items-center gap-1 w-full hover:text-primary-700', {
                                    [`font-semibold ${navStyles.AccordionTriggerActive}`]: isChapterActive,
                                }), children: [_jsx("span", { className: classNames(navStyles.AccordionTriggerIcon, 'i-ph-caret-right-bold scale-80 text-gray-300', {
                                            [navStyles.AccordionTriggerActive]: isChapterActive,
                                        }) }), _jsx("span", { children: chapter.title })] }), _jsx(Accordion.Content, { className: navStyles.AccordionContent, children: renderLessons(currentLesson, chapter, isPartActive, isChapterActive, onLinkClick) })] }) }, chapterIndex));
            }) }) }));
}
function renderLessons(currentLesson, chapter, isPartActive, isChapterActive, onLinkClick) {
    return (_jsx("ul", { className: "pl-9 mt-1.5", children: chapter.sections?.map((lesson, lessonIndex) => {
            const isActiveLesson = isPartActive && isChapterActive && lesson.id === currentLesson.id;
            return (_jsx("li", { className: "mr-3", children: _jsx("a", { onClick: onLinkClick, className: classNames('w-full inline-block border border-transparent pr-3 transition-theme text-tk-elements-breadcrumbs-dropdown-lessonTextColor hover:text-tk-elements-breadcrumbs-dropdown-lessonTextColorHover px-3 py-1 rounded-1', {
                        'bg-tk-elements-breadcrumbs-dropdown-lessonBackgroundColor': !isActiveLesson,
                        'font-semibold text-tk-elements-breadcrumbs-dropdown-lessonTextColorSelected bg-tk-elements-breadcrumbs-dropdown-lessonBackgroundColorSelected': isActiveLesson,
                    }), href: lesson.href, children: lesson.title }) }, lessonIndex));
        }) }));
}
